@@ -1,46 +1,26 @@
+#
+# This file is part of Redis
+#
+# This software is Copyright (c) 2013 by Pedro Melo, Damien Krotkine.
+#
+# This is free software, licensed under:
+#
+#   The Artistic License 2.0 (GPL Compatible)
+#
 package Redis::Hash;
+{
+  $Redis::Hash::VERSION = '1.973_01';
+}
+
+# ABSTRACT: tie Perl hashes to Redis hashes
+# VERSION
+# AUTHORITY
 
 use strict;
 use warnings;
 use Tie::Hash;
 use base qw/Redis Tie::StdHash/;
 
-=head1 NAME
-
-Redis::Hash - tie perl hashes into Redis
-
-=head1 SYNOPSYS
-
-    ## Create fake hash using keys like 'hash_prefix:KEY'
-    tie %my_hash, 'Redis::Hash', 'hash_prefix', @Redis_new_parameters;
-    
-    ## Treat the entire Redis database as a hash
-    tie %my_hash, 'Redis::Hash', undef, @Redis_new_parameters;
-    
-    $value = $my_list{$key};
-    $my_list{$key} = $value;
-    
-    @keys   = keys %my_hash;
-    @values = values %my_hash;
-    
-    %my_hash = reverse %my_hash;
-    
-    %my_hash = ();
-
-
-=head1 DESCRIPTION
-
-Ties a Perl hash to Redis. Note that it doesn't use Redis Hashes, but
-implements a fake hash using regular keys like "prefix:KEY".
-
-If no C<prefix> is given, it will tie the entire Redis database
-as a hash.
-
-Future versions will also allow you to use real Redis hash structures.
-
-
-=cut
-
 
 sub TIEHASH {
   my ($class, $prefix, @rest) = @_;
@@ -70,7 +50,7 @@ sub FIRSTKEY {
 sub NEXTKEY {
   my $self = shift;
 
-  my $key = shift @{$self->{prefix_keys}};
+  my $key = shift @{ $self->{prefix_keys} };
   return unless defined $key;
 
   my $p = $self->{prefix};
@@ -94,4 +74,70 @@ sub CLEAR {
   $self->{prefix_keys} = [];
 }
 
-1;
+
+1;    ## End of Redis::Hash
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Redis::Hash - tie Perl hashes to Redis hashes
+
+=head1 VERSION
+
+version 1.973_01
+
+=head1 DESCRIPTION
+
+Ties a Perl hash to Redis. Note that it doesn't use Redis Hashes, but
+implements a fake hash using regular keys like "prefix:KEY".
+
+If no C<prefix> is given, it will tie the entire Redis database as a hash.
+
+Future versions will also allow you to use real Redis hash structures.
+
+=head1 SYNOPSYS
+
+    ## Create fake hash using keys like 'hash_prefix:KEY'
+    tie %my_hash, 'Redis::Hash', 'hash_prefix', @Redis_new_parameters;
+
+    ## Treat the entire Redis database as a hash
+    tie %my_hash, 'Redis::Hash', undef, @Redis_new_parameters;
+
+    $value = $my_hash{$key};
+    $my_hash{$key} = $value;
+
+    @keys   = keys %my_hash;
+    @values = values %my_hash;
+
+    %my_hash = reverse %my_hash;
+
+    %my_hash = ();
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Pedro Melo <melo@cpan.org>
+
+=item *
+
+Damien Krotkine <dams@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Pedro Melo, Damien Krotkine.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=cut
